@@ -3,7 +3,9 @@ $LOAD_PATH.unshift File.expand_path('../../lib', __FILE__)
 unless ENV['MUTANT']
   begin
   require "coveralls"
-  Coveralls.wear!
+  Coveralls.wear! do
+    add_filter '/test/'
+  end
   rescue LoadError
   end
 end
@@ -15,4 +17,6 @@ end
 
 require 'minitest/autorun'
 
+Dir[File.expand_path('../support/**/*.rb', __FILE__)].each { |f| require f }
+
 require 'trollop'
